#!/bin/bash


KER_VER="$(uname -r)"
echo "Detected kernel version: $KER_VER"

if lsmod | grep -qw "^88XXau"; then
    echo "Default 88XXau kernel module already loaded"
    exit 0
fi

if ! [ -f /lib/modules/$KER_VER/kernel/drivers/net/wireless/88XXau.ko ]; then 
    echo "[WARNING] RTL8812AU default .ko missing!"
    exit 0
fi

echo "Enabling 88XXau to run on bootup..."
sed -i '/88XXau/d' /etc/modules
echo "Adding 88XXau kernel module to /etc/modules..."
echo 88XXau >> /etc/modules
if [ -f /etc/modprobe.d/blacklist-88XXau.conf ]; then
    echo "Removing 88XXau kernel module from blacklist"
    rm /etc/modprobe.d/blacklist-88XXau.conf
fi

if ! [ -f /etc/modprobe.d/blacklist-88XXau_vtx.conf ]; then
    echo "Stopping 88XXau_vtx from running on bootup, adding to blacklist"
    echo blacklist 88XXau_vtx >> /etc/modprobe.d/blacklist-88XXau_vtx.conf
fi

echo "Removing 88XXau_vtx kernel module..."
rmmod 88XXau_vtx
echo "Loading default 88XXau kernel module..."
insmod /lib/modules/$KER_VER/kernel/drivers/net/wireless/88XXau.ko
echo "Updating kernel module dependencies..."
/sbin/depmod -a "$KER_VER"